/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

/*
 * BoardPanel.java
 *
 * Created on 26.01.2010, 17:00:24
 */
package eventtalkboard;


/**
 *
 * @author hansolo
 */
public class BoardPanel extends javax.swing.JPanel implements java.awt.event.ActionListener
{
    private javax.swing.Timer checkEventTimer = new javax.swing.Timer(60000, this);
    private javax.swing.Timer setEventTimer = new javax.swing.Timer(8000, this);
    private int eventCounter = 0;
    private String eventTitle = "CONFERENCE NAME";
    private java.util.Date eventDate = new java.util.Date();
    private final java.text.DateFormat DF = new java.text.SimpleDateFormat("dd.MM.yyyy");
    private java.util.List<Event> eventList = new java.util.ArrayList<Event>();
    private java.util.List<EventRow> rowList = new java.util.ArrayList<EventRow>();

    /** Creates new form BoardPanel */
    public BoardPanel()
    {
        initComponents();        
        rowList.add(talk1);
        rowList.add(talk2);
        rowList.add(talk3);
        rowList.add(talk4);
        rowList.add(talk5);
        rowList.add(talk6);
        rowList.add(talk7);
        checkEventTimer.start();
    }

    public void addEvent(String time, String talk, String speaker, String location)
    {
        this.eventList.add(new Event(time, talk, speaker, location));
        checkEvents();
    }

    public void addEvent(Event event)
    {
        this.eventList.add(event);
        checkEvents();
    }

    public void removeEvent(Event event)
    {
        this.eventList.remove(event);
        checkEvents();
    }

    public String getEventTitle()
    {
        return this.eventTitle;
    }

    public void setEventTitle(String eventTitle)
    {
        this.eventTitle = eventTitle;
        eventTitleLabel.setText(eventTitle.toUpperCase());
    }

    public java.util.Date getEventDate()
    {
        return this.eventDate;
    }

    public void setEventDate(java.util.Date eventDate)
    {
        this.eventDate = eventDate;
        eventDateLabel.setText(DF.format(eventDate).toUpperCase());
    }

    private void orderEvents()
    {
        // Events in Liste nach Uhrzeit aufsteigend sortieren
        java.util.Collections.sort((java.util.List)eventList, new java.util.Comparator()
        {
            @Override
            public int compare(Object o1, Object o2)
            {
                long ts1 = ((Event) o1).getTimeStamp();
                long ts2 = ((Event) o2).getTimeStamp();
                return (ts1 > ts2 ) ?  1 : ( ts1 < ts2 ) ? -1 : ((String)o2).compareTo( (String)o1 );
            }
        });

        final java.text.DateFormat DATE_FORMAT = new java.text.SimpleDateFormat("dd.MM.yyyy HH:mm");
        java.util.Date date;
        for (Event event : eventList)
        {
            try
            {               
                date = DATE_FORMAT.parse(DF.format(eventDate) + " " + event.getTime());
                if (date.getTime() > (System.currentTimeMillis() - 600000) && date.getTime() < (System.currentTimeMillis() + 300000))
                {
                    event.setActive(true);                    
                }
                else
                {
                    event.setActive(false);                    
                }
            }
            catch (java.text.ParseException exception)
            {
                exception.printStackTrace();

            }
        }
    }

    private void checkEvents()
    {
        orderEvents();        

        // Remove events that are over
        long now = java.util.Calendar.getInstance().get( java.util.Calendar.HOUR_OF_DAY ) * 3600000 + java.util.Calendar.getInstance().get( java.util.Calendar.MINUTE ) * 60000;        
        java.util.ArrayList<Event> removeList = new java.util.ArrayList<Event>();
        for (Event event : eventList)
        {            
            if (event.getTimeStamp() + 300000 <= now)
            {
                removeList.add(event);
            }
        }
        for (Event event : removeList)
        {
            eventList.remove(event);
        }
        removeList.clear();

        setEvents();
    }

    private void setEvents()
    {
        eventCounter = 0;
        setEventTimer.start();
    }
    
    @Override
    public void actionPerformed(java.awt.event.ActionEvent event)
    {
        if (event.getSource().equals(checkEventTimer))
        {
            // Check the eventlist for upcoming events and reorganize the talk rows if needed
            checkEvents();
        }

        if (event.getSource().equals(setEventTimer))
        {
            if (eventCounter == rowList.size())
            {                
                setEventTimer.stop();
                return;
            }

            if (eventList.size() >= (eventCounter + 1))
            {                
                rowList.get(eventCounter).time.setText(eventList.get(eventCounter).getTime());
                rowList.get(eventCounter).talk.setText(eventList.get(eventCounter).getTalk());
                rowList.get(eventCounter).speaker.setText(eventList.get(eventCounter).getSpeaker());
                rowList.get(eventCounter).location.setText(eventList.get(eventCounter).getLocation());
                if (eventList.get(eventCounter).isActive())
                {
                    rowList.get(eventCounter).blinker1.setBlinking(true);
                    rowList.get(eventCounter).blinker2.setBlinking(true);
                }
                else
                {
                    rowList.get(eventCounter).blinker1.setBlinking(false);
                    rowList.get(eventCounter).blinker2.setBlinking(false);
                }
            }
            else
            {
                rowList.get(eventCounter).reset();
            }
            eventCounter++;
        }
    }

    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        flipBackgroundPanel1 = new eventtalkboard.FlipBackgroundPanel();
        talk1 = new eventtalkboard.EventRow();
        talk2 = new eventtalkboard.EventRow();
        talk3 = new eventtalkboard.EventRow();
        talk4 = new eventtalkboard.EventRow();
        analogClockPanel1 = new eventtalkboard.AnalogClockPanel();
        eventTitleLabel = new eventtalkboard.TextLabel();
        eventDateLabel = new eventtalkboard.TextLabel();
        timeLabel = new eventtalkboard.TextLabel();
        talkLabel = new eventtalkboard.TextLabel();
        speakerLabel = new eventtalkboard.TextLabel();
        locationLabel = new eventtalkboard.TextLabel();
        logoPanel = new eventtalkboard.LogoPanel();
        talk5 = new eventtalkboard.EventRow();
        talk6 = new eventtalkboard.EventRow();
        talk7 = new eventtalkboard.EventRow();

        flipBackgroundPanel1.setName("flipBackgroundPanel1"); // NOI18N

        talk1.setName("talk1"); // NOI18N

        talk2.setName("talk2"); // NOI18N

        talk3.setName("talk3"); // NOI18N

        talk4.setName("talk4"); // NOI18N

        analogClockPanel1.setName("analogClockPanel1"); // NOI18N

        org.jdesktop.layout.GroupLayout analogClockPanel1Layout = new org.jdesktop.layout.GroupLayout(analogClockPanel1);
        analogClockPanel1.setLayout(analogClockPanel1Layout);
        analogClockPanel1Layout.setHorizontalGroup(
            analogClockPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(0, 110, Short.MAX_VALUE)
        );
        analogClockPanel1Layout.setVerticalGroup(
            analogClockPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(0, 110, Short.MAX_VALUE)
        );

        eventTitleLabel.setText("EVENT TITLE");
        eventTitleLabel.setFont(new java.awt.Font("Arial Narrow", 1, 48));
        eventTitleLabel.setName("eventTitleLabel"); // NOI18N

        eventDateLabel.setText("DD.MM.YYYY");
        eventDateLabel.setFont(new java.awt.Font("Arial Narrow", 1, 36));
        eventDateLabel.setName("eventDateLabel"); // NOI18N

        timeLabel.setText("TIME");
        timeLabel.setFont(new java.awt.Font("Arial Narrow", 1, 20));
        timeLabel.setName("timeLabel"); // NOI18N

        talkLabel.setText("TALK");
        talkLabel.setFont(new java.awt.Font("Arial Narrow", 1, 20));
        talkLabel.setName("talkLabel"); // NOI18N

        speakerLabel.setText("SPEAKER");
        speakerLabel.setFont(new java.awt.Font("Arial Narrow", 1, 20));
        speakerLabel.setName("speakerLabel"); // NOI18N

        locationLabel.setText("LOCATION");
        locationLabel.setFont(new java.awt.Font("Arial Narrow", 1, 20));
        locationLabel.setName("locationLabel"); // NOI18N

        logoPanel.setName("logoPanel"); // NOI18N

        org.jdesktop.layout.GroupLayout logoPanelLayout = new org.jdesktop.layout.GroupLayout(logoPanel);
        logoPanel.setLayout(logoPanelLayout);
        logoPanelLayout.setHorizontalGroup(
            logoPanelLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(0, 230, Short.MAX_VALUE)
        );
        logoPanelLayout.setVerticalGroup(
            logoPanelLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(0, 140, Short.MAX_VALUE)
        );

        talk5.setName("talk5"); // NOI18N

        talk6.setName("talk6"); // NOI18N

        talk7.setName("talk7"); // NOI18N

        org.jdesktop.layout.GroupLayout flipBackgroundPanel1Layout = new org.jdesktop.layout.GroupLayout(flipBackgroundPanel1);
        flipBackgroundPanel1.setLayout(flipBackgroundPanel1Layout);
        flipBackgroundPanel1Layout.setHorizontalGroup(
            flipBackgroundPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(flipBackgroundPanel1Layout.createSequentialGroup()
                .addContainerGap()
                .add(flipBackgroundPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                    .add(flipBackgroundPanel1Layout.createSequentialGroup()
                        .add(flipBackgroundPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                            .add(flipBackgroundPanel1Layout.createSequentialGroup()
                                .add(22, 22, 22)
                                .add(timeLabel, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                            .add(analogClockPanel1, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                        .add(59, 59, 59)
                        .add(flipBackgroundPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                            .add(flipBackgroundPanel1Layout.createSequentialGroup()
                                .add(talkLabel, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED, 573, Short.MAX_VALUE)
                                .add(speakerLabel, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                                .add(386, 386, 386)
                                .add(locationLabel, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                                .add(229, 229, 229))
                            .add(flipBackgroundPanel1Layout.createSequentialGroup()
                                .add(flipBackgroundPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                                    .add(eventTitleLabel, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 1161, Short.MAX_VALUE)
                                    .add(eventDateLabel, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 1161, Short.MAX_VALUE))
                                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                                .add(logoPanel, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))))
                    .add(talk1, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                    .add(talk2, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                    .add(talk3, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                    .add(talk4, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                    .add(org.jdesktop.layout.GroupLayout.TRAILING, talk5, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                    .add(org.jdesktop.layout.GroupLayout.TRAILING, talk6, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                    .add(talk7, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                .addContainerGap())
        );
        flipBackgroundPanel1Layout.setVerticalGroup(
            flipBackgroundPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(flipBackgroundPanel1Layout.createSequentialGroup()
                .add(24, 24, 24)
                .add(flipBackgroundPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                    .add(logoPanel, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                    .add(flipBackgroundPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.TRAILING)
                        .add(analogClockPanel1, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                        .add(flipBackgroundPanel1Layout.createSequentialGroup()
                            .add(eventTitleLabel, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 65, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                            .addPreferredGap(org.jdesktop.layout.LayoutStyle.UNRELATED)
                            .add(eventDateLabel, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))))
                .add(31, 31, 31)
                .add(flipBackgroundPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                    .add(timeLabel, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                    .add(locationLabel, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                    .add(talkLabel, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                    .add(speakerLabel, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(talk1, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .add(18, 18, 18)
                .add(talk2, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .add(18, 18, 18)
                .add(talk3, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .add(18, 18, 18)
                .add(talk4, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .add(18, 18, 18)
                .add(talk5, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .add(18, 18, 18)
                .add(talk6, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .add(18, 18, 18)
                .add(talk7, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .addContainerGap(24, Short.MAX_VALUE))
        );

        org.jdesktop.layout.GroupLayout layout = new org.jdesktop.layout.GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(flipBackgroundPanel1, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 1608, Short.MAX_VALUE)
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(flipBackgroundPanel1, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 604, Short.MAX_VALUE)
        );
    }// </editor-fold>//GEN-END:initComponents
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private eventtalkboard.AnalogClockPanel analogClockPanel1;
    private eventtalkboard.TextLabel eventDateLabel;
    private eventtalkboard.TextLabel eventTitleLabel;
    private eventtalkboard.FlipBackgroundPanel flipBackgroundPanel1;
    private eventtalkboard.TextLabel locationLabel;
    public eventtalkboard.LogoPanel logoPanel;
    private eventtalkboard.TextLabel speakerLabel;
    private eventtalkboard.EventRow talk1;
    private eventtalkboard.EventRow talk2;
    private eventtalkboard.EventRow talk3;
    private eventtalkboard.EventRow talk4;
    private eventtalkboard.EventRow talk5;
    private eventtalkboard.EventRow talk6;
    private eventtalkboard.EventRow talk7;
    private eventtalkboard.TextLabel talkLabel;
    private eventtalkboard.TextLabel timeLabel;
    // End of variables declaration//GEN-END:variables
}
